OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Gjøremål",
    "Personal" : "Personlig",
    "{actor} created calendar {calendar}" : "{actor} opprettet kalenderen {calendar}",
    "You created calendar {calendar}" : "Du opprettet kalenderen {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} slettet kalenderen {calendar}",
    "You deleted calendar {calendar}" : "Du slettet kalenderen {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} oppdaterte kalenderen {calendar}",
    "You updated calendar {calendar}" : "Du oppdaterte kalenderen {calendar}",
    "You shared calendar {calendar} as public link" : "Du delte kalenderen {calendar} som offentlig lenke",
    "You removed public link for calendar {calendar}" : "Du fjernet offentlig lenke for kalenderen {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delte kalenderen {calendar} med deg",
    "You shared calendar {calendar} with {user}" : "Du delte kalenderen {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delte kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} opphevde delingen av kalenderen {calendar} med deg",
    "You unshared calendar {calendar} from {user}" : "Du opphevde delingen av kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} opphevde delingen av kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} opphevde delingen av kalender {calendar} med seg selv",
    "You shared calendar {calendar} with group {group}" : "Du delte kalender {calendar} med gruppe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delte kalenderen {calendar} med gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Du opphevde deling av kalenderen {calendar} med gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} opphevde deling av kalenderen {calendar} med gruppe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} opprettet en hendelse {event} i kalenderen {calendar}",
    "You created event {event} in calendar {calendar}" : "Du opprettet en hendelse {event} i kalenderen {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} slettet hendelsen {event} fra kalenderen {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du slettet hendelsen {event} fra kalenderen {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} oppdaterte hendelsen {event} i kalenderen {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du oppdaterte hendelsen {event} i kalenderen {calendar}",
    "Busy" : "Opptatt",
    "{actor} created todo {todo} in list {calendar}" : "{actor} opprettet en oppgaven {todo} i listen {calendar}",
    "You created todo {todo} in list {calendar}" : "Du opprettet en oppgave {todo} i listen {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} slettet gjøremålet {todo} fra listen {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du slettet gjøremålet {todo} fra listen {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} oppdaterte gjøremålet {todo} i listen {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du oppdaterte gjøremålet {todo} i listen {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} ferdigstilte gjøremålet {todo} i listen {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du ferdigstilte gjøremålet {todo} i listen {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} gjenåpnet gjøremålet {todo} i listen {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du gjenåpnet oppgaven {todo} i listen {calendar}",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> ble endret",
    "A calendar <strong>event</strong> was modified" : "En kalender <strong>hendelse</strong> ble endret",
    "A calendar <strong>todo</strong> was modified" : "En kalende <strong>gjøremål</strong> ble endret",
    "Contact birthdays" : "Kontakters fødelsdag",
    "Where:" : "Hvor:",
    "Description:" : "Beskrivelse:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Invitation canceled" : "Invitasjon tilbakekalt",
    "Hello %s," : "Hei %s,",
    "Invitation updated" : "Invitasjon oppdatert",
    "When:" : "Når:",
    "Link:" : "Lenke:",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Contacts" : "Kontakter",
    "WebDAV" : "WebDAV",
    "Technical details" : "Tekniske detaljer",
    "Remote Address: %s" : "Ekstern adresse: %s",
    "Request ID: %s" : "Forespørsel ID: %s",
    "Tentative" : "Foreløpig",
    "Save" : "Lagre",
    "Calendar server" : "Kalenderserver",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installer også {calendarappstoreopen} Kalender-appen {linkclose}, eller {calendardocopen} knytt datamaskinen og mobilen din for synkronisering ↗{linkclose}.",
    "Send invitations to attendees" : "Send invitasjoner til oppmøtte",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Vennligst sørg for å sette opp {emailopen}e-postinnstillingene{linkclose} på riktig måte.",
    "Automatically generate a birthday calendar" : "Lag fødelsdagskalender automatisk",
    "Birthday calendars will be generated by a background job." : "Fødselsdagskalender lages automatisk av en bakgrunnsjobb.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Derav vil de ikke være tilgjengelige umiddelbart etter at du har skrudd dem på, men vil vises etter en stund.",
    "Please make sure to properly set up the email settings above." : "Sett opp e-postinnstillingene ovenfor på riktig måte."
},
"nplurals=2; plural=(n != 1);");
